@@ -49,8 +49,7 @@
 #include <math.h>
 
 #include "kpLogCategories.h"
-#include <kimageio.h>
-#include <kio/netaccess.h>
+#include <kio/netaccess.h> // kdelibs4support
 #include <KLocalizedString>
 
 #include <qcolor.h>
