@@ -30,12 +30,11 @@
 
 #include "kpUrlFormatter.h"
 
-#include <kio/netaccess.h>
+#include <kio/netaccess.h> // kdelibs4support
 #include <KLocalizedString>
 #include <KMessageBox>
 #include "kpLogCategories.h"
 #include <kstringhandler.h>
-#include "kpLogCategories.h"
 
 #include <QDir>
 #include <QFile>
@@ -266,7 +265,7 @@ static void SaveToFile (kpColorCollectionPrivate *d, QIODevice *device)
    QTextStream str (device);
 
    QString description = d->desc.trimmed();
-   description = '#'+description.split( "\n", QString::KeepEmptyParts).join("\n#");
+   description = '#'+description.split( '\n', QString::KeepEmptyParts).join("\n#");
 
    str << "KDE RGB Palette\n";
    str << description << "\n";
