@@ -104,7 +104,7 @@ public:
     //  window without a document at all).
     kpMainWindow (kpDocument *newDoc);
 
-    virtual void finalizeGUI(KXMLGUIClient *client);
+    void finalizeGUI(KXMLGUIClient *client) override;
 
 private:
     void readGeneralSettings ();
@@ -115,14 +115,14 @@ private:
     // (only called for restoring a previous session e.g. starting KDE with
     //  a previously saved session; it's not called on normal KolourPaint
     //  startup)
-    virtual void readProperties (const KConfigGroup &configGroup);
+    void readProperties (const KConfigGroup &configGroup) override;
     // (only called for saving the current session e.g. logging out of KDE
     //  with the KolourPaint window open; it's not called on normal KolourPaint
     //  exit)
-    virtual void saveProperties (KConfigGroup &configGroup);
+    void saveProperties (KConfigGroup &configGroup) override;
 
 public:
-    ~kpMainWindow ();
+    ~kpMainWindow () override;
 
 public:
     kpDocument *document () const;
@@ -140,9 +140,9 @@ private:
 
     void setDocument (kpDocument *newDoc);
 
-    virtual void dragEnterEvent (QDragEnterEvent *e);
-    virtual void dropEvent (QDropEvent *e);
-    virtual void moveEvent (QMoveEvent *e);
+    void dragEnterEvent (QDragEnterEvent *e) override;
+    void dropEvent (QDropEvent *e) override;
+    void moveEvent (QMoveEvent *e) override;
 
 private slots:
     void slotScrollViewAfterScroll ();
@@ -391,7 +391,7 @@ private slots:
     void slotMail ();
 
     bool queryCloseDocument ();
-    virtual bool queryClose ();
+    bool queryClose () override;
 
     void slotClose ();
     void slotQuit ();
